@@ -116,6 +116,9 @@ class BaseConfig:
                                      "/ike2b/pool/company/area_distribution/park_company_count_by_special_tag"]
     # 飞书 webhook URL 常量定义  用于向指定的飞书机器人发送消息的 webhook 地址
     LIMIT_FS_WEBHOOK_URL = "https://open.feishu.cn/open-apis/bot/v2/hook/545140ef-8234-4167-9f0c-8ee72abae430"
+
+    # sql 注入验证器开关
+    SQL_INJECTION_ENABLE = False
     #
     #
     # # 外网地址
